@@ -36,8 +36,10 @@ class X12SegmentName(str, Enum):
     AAA = "AAA"
     AMT = "AMT"
     BHT = "BHT"
+    BPR = "BPR"
     CAS = "CAS"
     CLM = "CLM"
+    CLP = "CLP"
     CN1 = "CN1"
     CR1 = "CR1"
     CR2 = "CR2"
@@ -46,6 +48,7 @@ class X12SegmentName(str, Enum):
     CTP = "CTP"
     CUR = "CUR"
     DMG = "DMG"
+    DTM = "DTM"
     DTP = "DTP"
     EB = "EB"
     EQ = "EQ"
@@ -67,9 +70,11 @@ class X12SegmentName(str, Enum):
     LS = "LS"
     LX = "LX"
     MEA = "MEA"
+    MIA = "MIA"
     MOA = "MOA"
     MPI = "MPI"
     MSG = "MSG"
+    N1 = "N1"
     N3 = "N3"
     N4 = "N4"
     NM1 = "NM1"
@@ -77,18 +82,23 @@ class X12SegmentName(str, Enum):
     OI = "OI"
     PAT = "PAT"
     PER = "PER"
+    PLB = "PLB"
     PRV = "PRV"
     PS1 = "PS1"
     PWK = "PWK"
     QTY = "QTY"
+    RDM = "RDM"
     REF = "REF"
     SBR = "SBR"
     SE = "SE"
     ST = "ST"
+    SVC = "SVC"
     SV1 = "SV1"
     SV5 = "SV5"
     SVD = "SVD"
     TRN = "TRN"
+    TS2 = "TS2"
+    TS3 = "TS3"
 
 
 class X12Segment(abc.ABC, BaseModel):
